#
# spec file for package sigrok-cli
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Summary:        Logic Analyzer Command Line Tool
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Electronics

Name:           sigrok-cli
Version:        0.7.2
Release:        1.13
URL:            https://sigrok.org
BuildRequires:  glib2-devel
BuildRequires:  libsigrok-devel >= 0.4.0
BuildRequires:  libsigrokdecode-devel >= 0.4.0
Source0:        https://sigrok.org/download/source/sigrok-cli/%{name}-%{version}.tar.gz

%description
The sigrok project aims at creating a portable, cross-platform,
Free/Libre/Open-Source logic analyzer software that supports various
logic analyzer hardware products.

sigrok-cli is a command-line tool written in C, which uses both
libsigrok and libsigrokdecode to provide the basic sigrok
functionality from the command-line. Among other things, it's useful
for scripting purposes.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc NEWS README
%doc %_mandir/*/*
%_bindir/*
%dir %{_datadir}/applications/
%{_datadir}/applications/org.sigrok.sigrok-cli.desktop
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/scalable/
%dir %{_datadir}/icons/hicolor/scalable/apps/
%{_datadir}/icons/hicolor/scalable/apps/sigrok-cli.svg

%changelog
* Mon Mar  1 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.7.2, for details see include NEWS file or
  https://www.sigrok.org/blog/sigrok-cli-072-released
- Spec file cleanup, remove unused autotools dependencies.
* Sun Mar 22 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.7.1
  * Command line option changes:
  - Add the --protocol-decoder-samplenum option.
  * Scan: Fix auto-select of non-demo device, if there's only one (bug #848).
  * Protocol decoding: Always print colon after protocol decoder ID.
  * input:
  - Increase chunk size to 4MB (large performance improvements).
  - Make read from stdin work with the presence of -I specs.
  * Manpage:
  - Fix outdated references to -V (it's -L now).
  - Don't list specific output formats, only mention -L.
  - Improve decoder stacking documentation.
  - Mention currently unsupported channel name auto-matching.
  - Various example invocation improvements (bug #1181).
  * Fix invalid frame limit error reporting.
  * Bugfix in order to make sr_session_stop() actually work.
  * Add a .desktop file and an icon.
  * Don't unnecessarily run the 'analog' output module on data sources
    which don't have analog channels, thus improving performance.
  * HACKING: Prefer git pull requests over mailing list patches.
- Spec file modernization and cleanup
* Tue Jun 13 2017 stefan.bruens@rwth-aachen.de
- update to version 0.7.0
  * Update sigrok-cli to new APIs libsigrok/libsigrokdecode APIs
  * -P <decoder> --show:
  - List the binary output classes of the decoder.
  - List the possible input and output IDs of the decoder.
  * --help:
  - Clarify that --show also lists input/output format options,
    as well as protocol decoder options (bug #851).
  - Show a few typical invocations of e.g. --samples/--time/--continuous.
  * Add an -L|--list-supported option; this used to be part of -V (bug #604).
  * Drop the superfluous -S|--protocol-decoder-stack option.
  * Allow multiple -P options to decode multiple stacks (bug #868).
* Sat Jan 30 2016 stefan.bruens@rwth-aachen.de
- update to version 0.6.0
  * new options:
  - Add --get: retrieve a variable value from a device
  - Add -T|--transform-module
  * adapt to new libsigrok 0.4.0 API
  * various small changes
* Fri Sep 25 2015 stefan.bruens@rwth-aachen.de
- Track GIT version (upcoming 0.6.0)
* Mon Jun  2 2014 bugs@vdm-design.de
- Sync .spec with the one from rmax
* Fri May 30 2014 bugs@vdm-design.de
- Update to version 0.5.0
  * Update sigrok-cli to the new APIs from both libsigrok 0.3.0 and also
  libsigrokdecode 0.3.0.
  * Add support for the new channel groups feature in libsigrok.
  * Report channel groups (drivers) and annotation rows (PDs) in --show.
  * The protocol decoder output verbosity now depends on the --loglevel used.
  * Only show the longest annotation per default if multiple are provided by
  the PD. Higher numbers for the -l option will show them all.
  * Allow both hex and decimal numbers as values for command-line options.
  * Add support for an explicit "sigrok" file format option that can be
  used with --input-format or --output-format (bug #131).
  * If no PD annotation class is specified, default to showing all (bug #149).
  * Fix an issue when running decoders with optional channels (bug #138).
  * Report possible PD option values in --show output (bug #330).
  * Allow saving of output in continuous mode (bug #122).
  * Add support for libsigrok's SR_T_DOUBLE_RANGE config key (bug #335).
  * Add support for config keys of type G_VARIANT_TYPE_INT32.
  * Fix a bug which involved trying to save a file containing no data.
  * Fix an internal probe ordering issue (bug #268).
  * Fix various memory leak issues (bug #134, others).
  * Fix a bug causing samplerates in session files being zero (bug #340).
  * Fix segfault during analog acquisition without '-O analog' (bugs #90, #105).
  * Fix a compile issue when building without libsigrokdecode (bug #351).
  * Command line option changes:
  - Add the -g|--channel-group option.
  - Add the -M option (for PD meta output type support).
  - Add the -B option (for PD binary output type support).
  - Rename the -p|--probes option to -C|--channels.
  * Various improvements to the NSIS file for better Windows installer support.
  - Ship (redistributable) firmware files in the Windows installer.
  - Ship libusb0.dll in the Windows installer (bug #243).
  - Ship zadig.exe and zadig_xp.exe in the Windows installer.
  - Ship all sample files from sigrok-dumps in the Windows installer.
  - Don't ship/run the full Python MSI installer, only the required files.
  - Fix a working directory issue in the installer.
  * Build system:
  - Use a non-recursive automake setup (fewer files, less clutter).
  - configure output: Show which libs are required and which are optional.
  * manpage: Various documentation updates.
* Wed Jan 16 2013 max@suse.com
- Initial packaging from git snapshot.
